@@ -2,20 +2,34 @@ import time
 
 from datetime import datetime
 from typing import Any, List
+from enum import Enum
 
 from .__level import __Level as Level
 
 
+class MessageStructure(Enum):
+    TIMESTAMP = time.struct_time,
+    IDENTIFIER = str,
+    CONTENT = Any,
+    LEVEL = Level
+
+
 class __Message:
     identifier: str = None
     content: str = None
     level: Level = Level.INFO
 
-    def __init__(self, timestamp: time.struct_time, identifier: str, content: Any, level: Level):
-        self.timestamp = timestamp
-        self.identifier: str = identifier
-        self.content: str = self.__convert_to_str(content)
-        self.level: Level = level
+    def __init__(
+            self,
+            timestamp: MessageStructure.TIMESTAMP.value,
+            identifier: MessageStructure.IDENTIFIER.value,
+            content: MessageStructure.CONTENT.value,
+            level: MessageStructure.LEVEL.value
+    ):
+        self.timestamp: MessageStructure.TIMESTAMP.value = timestamp
+        self.identifier: MessageStructure.IDENTIFIER.value = identifier
+        self.content: MessageStructure.CONTENT.value = self.__convert_to_str(content)
+        self.level: MessageStructure.LEVEL.value = level
 
     @staticmethod
     def __convert_to_str(content: Any) -> str:
